@@ -1,12 +1,11 @@
 """
-Utility functions and constants for UltraNLP
+Utility constants for UltraNLP
 """
 
 from enum import Enum
-from typing import Dict, Any
 
 class TokenType(Enum):
-    """Token type enumeration for memory efficiency"""
+    """Token type enumeration"""
     WORD = 1
     NUMBER = 2
     EMAIL = 3
@@ -22,7 +21,7 @@ class TokenType(Enum):
     CONTRACTION = 13
     HYPHENATED = 14
 
-# Default processing options
+# Default options
 DEFAULT_CLEAN_OPTIONS = {
     'lowercase': True,
     'remove_html': True,
